# Markdown2anki themes

## Table of contents
- Dark themes:
    - [Rose Pine](#Rose-Pine)
    - [Catpuccin Macchiato](#Catpuccin-Macchiato)
- Light themes:
    - [Rose Pine Dawn](#Rose-Pine-Dawn)
    - [Catpuccin Latte](#Catpuccin-Latte)

---

## Rose Pine
Inspired by: https://rosepinetheme.com/
![A demo image of the rose pine theme](./docs/rose-pine.webp)

## Rose Pine Dawn
Inspired by: https://rosepinetheme.com/
![A demo image of the rose pine dawn theme](./docs/rose-pine-dawn.webp)

## Catpuccin Macchiato
Inspired by: https://github.com/catppuccin/catppuccin
![A demo image of the catpuccin macchiato theme](./docs/catpuccin-macchiato.webp)

## Catpuccin Latte
Inspired by: https://github.com/catppuccin/catppuccin
![A demo image of the catpuccin latte theme](./docs/catpuccin-latte.webp)
